@@ -186,11 +186,10 @@ kill_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 {
 	ProcData *procdata = data;
 	
-	if (id == 100) 
-		kill_process (procdata, kill_signal);
-	
 	gtk_widget_destroy (GTK_WIDGET (dialog));
-		
+
+	if (id == 100) 
+		kill_process (procdata, kill_signal);		
 }
 
 void
@@ -580,7 +579,7 @@ bg_color_changed (GnomeColorPicker *cp, guint r, guint g, guint b,
 	GConfClient *client = procdata->client;
 	gchar *color;
 	
-	color = g_strdup_printf("#%02x%02x%02x", r, g, b);
+	color = g_strdup_printf("#%04x%04x%04x", r, g, b);
 	gconf_client_set_string (client, "/apps/procman/bg_color", color, NULL);
 	g_free (color);
 }
@@ -593,7 +592,7 @@ frame_color_changed (GnomeColorPicker *cp, guint r, guint g, guint b,
 	GConfClient *client = procdata->client;
 	gchar *color;
 	
-	color = g_strdup_printf("#%02x%02x%02x", r, g, b);
+	color = g_strdup_printf("#%04x%04x%04x", r, g, b);
 	gconf_client_set_string (client, "/apps/procman/frame_color", color, NULL);
 	g_free (color);
 }
@@ -750,7 +749,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	
 	proc_box = gtk_vbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (proc_box), 12);
-	tab_label = gtk_label_new_with_mnemonic (_("Process Listing"));
+	tab_label = gtk_label_new (_("Process Listing"));
 	gtk_widget_show (tab_label);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), proc_box, tab_label);
 	
@@ -837,7 +836,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	
 	sys_box = gtk_vbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (sys_box), 12);
-	tab_label = gtk_label_new_with_mnemonic (_("Resource Monitor"));
+	tab_label = gtk_label_new (_("Resource Monitor"));
 	gtk_widget_show (tab_label);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label);
 	
